Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Coordinate ¶
type CqZone ¶
type CqZone struct {
Number int `json:"number"`
Name string `json:"name"`
Center Coordinate `json:"center"`
GeoJSON GeoJSON `json:"geojson"`
}
func GetZoneByCoordinate ¶
func GetZoneByCoordinate(c Coordinate) (CqZone, bool)
func GetZoneByNumber ¶
type FeatureCollection ¶
FeatureCollection represents a collection of GeoJSON features.
func GetGeoJSON ¶ added in v1.0.1
func GetGeoJSON() FeatureCollection
type GeoJSON ¶
type GeoJSON struct {
Type string `json:"type"`
Properties Properties `json:"properties"`
Geometry Geometry `json:"geometry"`
}
GeoJSON represents a GeoJSON feature with a type, properties, and geometry.
type Geometry ¶
Geometry defines a GeoJSON geometry object, represented by a type and a nested array of coordinates.
type Properties ¶
type Properties struct {
Name string `json:"name"`
Number int `json:"number"`
Center Coordinate `json:"center"`
}
Properties is a structure representing various attributes including infos, a number, and a central coordinate.
Click to show internal directories.
Click to hide internal directories.